summaryrefslogtreecommitdiff
path: root/jstests/ssl
diff options
context:
space:
mode:
authorAmalia Hawkins <amalia.hawkins@10gen.com>2014-09-08 15:18:34 -0400
committerAmalia Hawkins <amalia.hawkins@10gen.com>2014-09-11 16:02:49 -0400
commit4c429ebe0a44521a293103c8e3b2fb90f14f056e (patch)
tree7a4d60ade894c0cd0a5ede99a6abed0fd58f4e52 /jstests/ssl
parentf5f42d6c684b8e779aef6889b800235d7417afcb (diff)
downloadmongo-4c429ebe0a44521a293103c8e3b2fb90f14f056e.tar.gz
SERVER-14977: add new alias for sslWeakCertificateValidation option
Diffstat (limited to 'jstests/ssl')
-rw-r--r--jstests/ssl/ssl_weak.js7
1 files changed, 3 insertions, 4 deletions
diff --git a/jstests/ssl/ssl_weak.js b/jstests/ssl/ssl_weak.js
index b66429b0ed4..d18500842a2 100644
--- a/jstests/ssl/ssl_weak.js
+++ b/jstests/ssl/ssl_weak.js
@@ -6,13 +6,13 @@ ports = allocatePorts( 2 );
var baseName = "jstests_ssl_ssl_weak";
// Test that connecting with no client certificate and --sslWeakCertificateValidation connects
// successfully.
var md = startMongod( "--port", ports[0], "--dbpath", MongoRunner.dataPath + baseName + "1",
"--sslMode", "requireSSL",
"--sslPEMKeyFile", "jstests/libs/server.pem",
"--sslCAFile", "jstests/libs/ca.pem",
- "--sslWeakCertificateValidation");
+ "--sslAllowConnectionsWithoutCertificates");
var mongo = runMongoProgram("mongo", "--port", ports[0], "--ssl",
"--eval", ";");
@@ -20,7 +20,6 @@ var mongo = runMongoProgram("mongo", "--port", ports[0], "--ssl",
// 0 is the exit code for success
assert(mongo==0);
-
// Test that connecting with a valid client certificate connects successfully.
mongo = runMongoProgram("mongo", "--port", ports[0], "--ssl",
"--sslPEMKeyFile", "jstests/libs/client.pem",
@@ -6,13 +6,13 @@ ports = allocatePorts( 2 );
var baseName = "jstests_ssl_ssl_weak";
-// Test that connecting with no client certificate and --sslWeakCertificateValidation connects
-// successfully.
+// Test that connecting with no client certificate and --sslAllowConnectionsWithoutCertificates
+// (an alias for sslWeakCertificateValidation) connects successfully.
var md = startMongod( "--port", ports[0], "--dbpath", MongoRunner.dataPath + baseName + "1",
"--sslMode", "requireSSL",